@@ -60,8 +60,10 @@ EXTERNAL_MODS = {
     #"m_build_info",
     #"m_optim_dumper",
     "libxc_functionals",
-    #Scale-UP for effective models
-    "scup_global"
+    # Scale-UP for effective models
+    "scup_global",
+    # GreenX library (temporary version)
+    "gx_minimax",
 }
 
 
@@ -607,7 +609,11 @@ class AbinitProject(NotebookWriter):
             1. new files/directories have been added
             2. source files have been changed
         """
-        if set(self.dirpaths) != set(self.get_dirpaths()): return True
+        try:
+            if set(self.dirpaths) != set(self.get_dirpaths()): return True
+        except RuntimeError:
+            return True
+
         # FIXME: Return immediately if new files have been added...
 
         # Compare time of most recent content modification.
