@@ -1,10 +1,10 @@
 #!/bin/bash
 #
-# Copyright (C) 2011-2021 ABINIT Group (Jean-Michel Beuken)
+# Copyright (C) 2011-2022 ABINIT Group (Jean-Michel Beuken)
 #
 # This file is part of the ABINIT software package. For license information,
 # please see the COPYING file in the top-level directory of the ABINIT source
 # distribution.
 #
 
-sed -i -e 's/ -little/& \| -library/' -e 's/\-\\#\\#\\#/& -dryrun/' configure
+#sed -i -e 's/ -little/& \| -library/' -e 's/\-\\#\\#\\#/& -dryrun/' configure
