@@ -30,8 +30,13 @@ class QptAnalyzer(object):
                  smearing=0.00367,
                  temperatures=None,
                  omegase=None,
+                 amu=None,
                  asr=True,
                  mu=None,
+                 double_smearing = False,
+                 smearing_width = 0.0367,
+                 smearing_above = 0.00367,
+                 smearing_below = 0.00367,
                  ):
 
         # Files
@@ -51,6 +56,12 @@ class QptAnalyzer(object):
         self.omegase = omegase if omegase else list()
         self.temperatures = temperatures if temperatures else list()
         self.mu = mu
+        self.amu = amu
+
+        self.double_smearing = double_smearing
+        self.smearing_width = smearing_width
+        self.smearing_above = smearing_above
+        self.smearing_below = smearing_below
 
     @property
     def nkpt(self):
@@ -63,6 +74,17 @@ class QptAnalyzer(object):
         else:
             raise Exception("Don't know nkpt. No files to read.")
 
+    @property
+    def kpts(self):
+        if self.eigr2d.fname:
+            return self.eigr2d.kpt
+        elif self.fan.fname:
+            return self.fan.kpt
+        elif self.gkk.fname:
+            return self.gkk.kpt
+        else:
+            raise Exception("Don't know kpt. No files to read.")
+
     @property
     def nband(self):
         if self.eigr2d.fname:
@@ -117,15 +139,20 @@ class QptAnalyzer(object):
             if f.fname:
                 f.read_nc()
 
+        if self.amu is not None:
+            self.ddb.set_amu(self.amu)
+
         self.ddb.compute_dynmat()
 
     def read_ddb(self):
         """Read the ddb and diagonalize the matrix, setting omega."""
         self.ddb.read_nc()
+        if self.amu is not None:
+            self.ddb.set_amu(self.amu)
         self.ddb.compute_dynmat()
 
     def read_zero_files(self):
-        """Read all nc files that are not specifically related to q=0."""
+        """Read all nc files that are related to q=0."""
         for f in (self.eig0, self.eigr2d0, self.fan0, self.gkk0):
             if f.fname:
                 f.read_nc()
@@ -197,8 +224,65 @@ class QptAnalyzer(object):
         """
         return (self.get_max_val() + self.get_min_cond()) / 2.0
 
+    def get_eta(self, omega_se):
+        """
+        Get the imaginary broadening parameter,
+        which may depend on frequency. 
+        
+        Returns: eta[nkpt, nband, nomegase]
+        """
+
+        # nkpt, nband
+        occ0 = self.eig0.get_fermi_function_T0(self.mu)[0,:,:]
+
+        # nkpt, nband
+        signs = (2 * occ0 - 1)
+
+        nomegase = len(omega_se)
+        values = np.zeros(nomegase, dtype=float)
+        #abso = np.abs(omega_se)
+
+        if self.double_smearing:
+
+            eta1 = self.smearing_below
+            eta2 = self.smearing
+            eta3 = self.smearing_above
+            w = self.smearing_width
+
+            for i, o in enumerate(omega_se):
+
+                if o < -w:
+                    values[i] = eta1
+                elif o <= 0.:
+                    values[i] = eta2 + (eta1-eta2) * abs(o) / w
+                elif o < w:
+                    values[i] = eta2 + (eta3-eta2) * abs(o) / w
+                else:
+                    values[i] = eta3
+
+        else:
+            values[:] = self.smearing
+
+        eta = einsum('kn,l->knl', signs, values) * 1j 
+
+        return eta
+
     @staticmethod
-    def reduce_array(arr, mode=False, temperature=False, omega=False):
+    def get_se_indices(mode=False, temperature=False, omega=False):
+        """Get the indices string corresponding to the self-energy dimensions"""
+        indices = ''
+        if mode:
+            indices += 'o'
+        if temperature:
+            indices += 't'
+        if omega:
+            indices += 'l'
+        indices += 'kn'
+        return indices
+
+    @staticmethod
+    def reduce_array(arr, mode=False, temperature=False, omega=False,
+                     shape=None):
         """
         Eliminate dimensions from an array of shape
         (nmode, ntemp, nomegase, nkpt, nband)
@@ -210,22 +294,31 @@ class QptAnalyzer(object):
             Keep the second dimension
         omega:
             Keep the third dimension
+        shape: 'otlkn'
+            Any subset of the initial indices, in any order.
+            Reshaping the array should be avoided if unnecessary.
         """
-        # Find the final order of 
-        final_indices = ''
-        if mode:
-            final_indices += 'o'
-        if temperature:
-            final_indices += 't'
-        if omega:
-            final_indices += 'l'
-        final_indices += 'kn'
 
-        summation = 'otlkn->' + final_indices
+        initial_indices = 'otlkn'
+
+        final_indices = QptAnalyzer.get_se_indices(
+            mode=mode, temperature=temperature, omega=omega)
+
+        if shape is not None:
+
+            if bool(shape.strip(initial_indices)):
+                raise Exception('shape ({}) must be a new combination of ' +
+                                'the intitial indices ({}).'.format(
+                                 shape, initial_indices))
+
+            final_indices = shape
+
+        summation = initial_indices + '->' + final_indices
 
         return einsum(summation, arr)
 
-    def get_fan_ddw_sternheimer(self, mode=False, omega=False, temperature=False):
+    def get_fan_ddw_sternheimer(self,
+        mode=False, omega=False, temperature=False, shape=None):
         """
         Compute the fan and ddw contribution to the self-energy
         obtained from the Sternheimer equation,
@@ -281,9 +374,10 @@ class QptAnalyzer(object):
         ddw = einsum('otkn,l->otlkn', ddw, odep)
 
         # Reduce the arrays
-        fan = self.reduce_array(fan, mode=mode, temperature=temperature, omega=omega)
-        ddw = self.reduce_array(ddw, mode=mode, temperature=temperature, omega=omega)
-
+        fan = self.reduce_array(fan, mode=mode, temperature=temperature,
+                                omega=omega, shape=shape)
+        ddw = self.reduce_array(ddw, mode=mode, temperature=temperature,
+                                omega=omega, shape=shape)
         return fan, ddw
     
     def get_fan_ddw_gkk2_active(self):
@@ -299,19 +393,24 @@ class QptAnalyzer(object):
             raise Exception('You should provide GKK files or FAN files '
                             'to compute active space contribution.')
 
-        # Get reduced displacement (scaled with frequency)
-        displ_red_FAN2, displ_red_DDW2 = self.ddb.get_reduced_displ_squared()
-
         if self.use_gkk:
-            gkk2 = self.gkk.get_gkk_squared()
-            gkk02 = self.gkk0.get_gkk_squared()
+
+            #gkk2 = self.gkk.get_gkk_squared()
+            #gkk02 = self.gkk0.get_gkk_squared()
+
+            fan = np.abs(self.gkk.get_gkk_mode(self.ddb)) ** 2
+            ddw = self.gkk0.get_gkk2_DW_mode(self.ddb)
+
         else:
+            # Get reduced displacement (scaled with frequency)
+            displ_red_FAN2, displ_red_DDW2 = self.ddb.get_reduced_displ_squared()
+
             gkk2 = self.fan.FAN
             gkk02 = self.fan0.FAN
 
-        # nkpt, nband, nband, nmode
-        fan = einsum('kniajbm,oabij->knmo', gkk2, displ_red_FAN2)
-        ddw = einsum('kniajbm,oabij->knmo', gkk02, displ_red_DDW2)
+            # nkpt, nband, nband, nmode
+            fan = einsum('kniajbm,oabij->knmo', gkk2, displ_red_FAN2)
+            ddw = einsum('kniajbm,oabij->knmo', gkk02, displ_red_DDW2)
 
         # Enforce the diagonal coupling terms to be zero at Gamma
         ddw = self.eig0.symmetrize_fan_degen(ddw)
@@ -321,7 +420,7 @@ class QptAnalyzer(object):
         return fan, ddw
     
     def get_fan_ddw_active(self, mode=False, omega=False, temperature=False,
-                           dynamical=True):
+                           dynamical=True, shape=None):
         """
         Compute the fan and ddw contributions to the self-energy
         from the active space, that is, the the lower bands.
@@ -415,7 +514,8 @@ class QptAnalyzer(object):
 
         # Reduce the arrays
         ddw = self.reduce_array(ddw, mode=mode,
-                                temperature=temperature, omega=omega)
+                                temperature=temperature, omega=omega,
+                                shape=shape)
 
 
         # Fan term
@@ -435,7 +535,10 @@ class QptAnalyzer(object):
               + einsum('knt,o->knot', occ[0,:,:,:], ones(nmode)))
 
         # nkpt, nband
-        eta = (2 * occ0 - 1) * self.smearing * 1j
+        #eta = (2 * occ0 - 1) * self.smearing * 1j
+
+        # nkpt, nband, nomegase
+        eta = self.get_eta(omega_se)
 
         for jband in range(nband):
 
@@ -443,12 +546,16 @@ class QptAnalyzer(object):
             delta_E = (
                 self.eig0.EIG[0,:,:].real
               - einsum('k,n->kn', self.eigq.EIG[0,:,jband].real, ones(nband))
-              - eta)
+              )
     
             # nkpt, nband, nomegase
-            delta_E_omega = (einsum('kn,l->knl', delta_E, ones(nomegase))
-                           + einsum('kn,l->knl', ones((nkpt,nband)), omega_se))
+            delta_E_omega = (
+                  einsum('kn,l->knl', delta_E, ones(nomegase))
+                + einsum('kn,l->knl', ones((nkpt,nband)), omega_se)
+                - eta
+                )
     
+            # Emission term
             # nkpt, nband, nomegase, nmode
             deno1 = (einsum('knl,o->knlo', delta_E_omega, ones(nmode))
                    - einsum('knl,o->knlo', ones((nkpt,nband,nomegase)), omega_q))
@@ -458,6 +565,7 @@ class QptAnalyzer(object):
     
             del deno1
     
+            # Absorption term
             # nkpt, nband, nomegase, nmode
             deno2 = (einsum('knl,o->knlo', delta_E_omega, ones(nmode))
                    + einsum('knl,o->knlo', ones((nkpt,nband,nomegase)), omega_q))
@@ -477,35 +585,48 @@ class QptAnalyzer(object):
             del div1, div2
       
         # Reduce the arrays
-        fan = self.reduce_array(fan, mode=mode, temperature=temperature, omega=omega)
+        fan = self.reduce_array(fan, mode=mode, temperature=temperature,
+                                omega=omega, shape=shape)
 
         return fan, ddw
 
     def get_fan_ddw(self, mode=False, temperature=False,
-                    omega=False, dynamical=False):
+                    omega=False, dynamical=False, shape=None):
+        """
+        Compute the sum of the Fan and the Diagonal Debye-Waller term.
+
+        Keyword arguments
+        -----------------
+
+        mode:
+            Keep mode decomposition (additional dimension)
+        temperature:
+            Inlcude temperature depdencente (additional dimension).
+        omega:
+            Inlcude frequency depdencente (additional dimension).
+        dynamical:
+            Use the full dynamical theory by including the phonon frequencies
+            in the location of the poles of the self-energy.
+
+        """
 
         kwargs = dict(
             mode=mode,
             temperature=temperature,
             omega=omega,
-            dynamical=dynamical)
-
-        fan_stern, ddw_stern = self.get_fan_ddw_sternheimer(
-            mode=mode,
-            temperature=temperature,
-            omega=omega,
+            shape=shape,
             )
-        fan_active, ddw_active = self.get_fan_ddw_active(
-            mode=mode,
-            temperature=temperature,
-            omega=omega,
-            dynamical=dynamical)
+
+        fan_stern, ddw_stern = self.get_fan_ddw_sternheimer(**kwargs)
+        fan_active, ddw_active = self.get_fan_ddw_active(dynamical=dynamical,
+                                                         **kwargs)
 
         fan = fan_active + fan_stern
         ddw = ddw_active + ddw_stern
 
         return fan, ddw
 
+
     def get_self_energy(self,
                         mode=False,
                         temperature=False,
@@ -515,32 +636,57 @@ class QptAnalyzer(object):
                         only_active=False,
                         only_fan=False,
                         only_ddw=False,
+                        real=False,
+                        imag=False,
+                        shape=None,
                         ):
+        """
+        Compute the self energy with various options to separate the terms
+        into separate fan / ddw, or active / sternheimer.
+
+        Keyword arguments
+        -----------------
+
+        mode:
+            Keep mode decomposition (additional dimension)
+        temperature:
+            Inlcude temperature depdencente (additional dimension).
+        omega:
+            Inlcude frequency depdencente (additional dimension).
+        dynamical:
+            Use the full dynamical theory by including the phonon frequencies
+            in the location of the poles of the self-energy.
+
+        only_sternheimer:
+            Only include the (frequency independent) Sternheimer part.
+        only_active:
+            Only include the "active" part contribution.
+        only_fan:
+            Only include the (frequency dependent) Fan term.
+        only_ddw:
+            Only include the (frequency independent) diagonal Debye-Waller term.
+
+        """
+
+        kwargs = dict(
+            mode=mode,
+            temperature=temperature,
+            omega=omega,
+            #shape=shape,
+            )
 
         if only_sternheimer and only_active:
             raise Exception(
             'only_sternheimer and only_active cannot be True at the same time')
 
         elif only_sternheimer:
-            fan, ddw = self.get_fan_ddw_sternheimer(
-                mode=mode,
-                temperature=temperature,
-                omega=omega,
-                )
+            fan, ddw = self.get_fan_ddw_sternheimer(**kwargs)
 
         elif only_active:
-            fan, ddw = self.get_fan_ddw_active(
-                mode=mode,
-                temperature=temperature,
-                omega=omega,
-                dynamical=dynamical)
+            fan, ddw = self.get_fan_ddw_active(dynamical=dynamical, **kwargs)
 
         else:
-            fan, ddw = self.get_fan_ddw(
-                mode=mode,
-                temperature=temperature,
-                omega=omega,
-                dynamical=dynamical)
+            fan, ddw = self.get_fan_ddw(dynamical=dynamical, **kwargs)
 
         if only_fan:
             se_q = fan
@@ -551,12 +697,24 @@ class QptAnalyzer(object):
 
         se = self.wtq * se_q
         se = self.eig0.make_average(se)
-    
+
+        if real:
+            se = se.real
+        elif imag:
+            se = se.imag
+
+        # Note that we must not reshape before calling eig0.make_average
+        if shape is not None:
+            initial_indices = self.get_se_indices(
+                mode=mode, temperature=temperature, omega=omega)
+            summation = initial_indices + '->' + shape
+            se = einsum(summation, se)
+
         return se
 
 
     def get_broadening(self, mode=False, temperature=False,
-                       omega=False, dynamical=True):
+                       omega=False, dynamical=True, shape=None):
         """
         Compute the zp broadening contribution from one q-point in a dynamical scheme.
         Only take the active space contribution.
@@ -659,11 +817,19 @@ class QptAnalyzer(object):
 
         # Reduce the arrays
         broadening = self.reduce_array(broadening, mode=mode,
-                                       temperature=temperature, omega=omega)
+                                       temperature=temperature,
+                                       omega=omega)
 
         broadening *= self.wtq
         broadening = self.eig0.make_average(broadening)
 
+        # Note that we must not reshape before calling eig0.make_average
+        if shape is not None:
+            initial_indices = self.get_se_indices(
+                mode=mode, temperature=temperature, omega=omega)
+            summation = initial_indices + '->' + shape
+            broadening = einsum(summation, broadening)
+
         return broadening
 
 
@@ -686,9 +852,8 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=False,
+            shape='knl'
             )
-        # nkpt, nband, nomegase, nband
-        self.sigma = einsum('lkn->knl', self.sigma) # FIXME why??
         return self.sigma
 
     def get_td_self_energy(self):
@@ -710,9 +875,9 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=False,
+            shape='knlt',
             )
         # nkpt, nband, nomegase, nband
-        self.sigma = einsum('tlkn->knlt', self.sigma) # FIXME why??
         return self.sigma
 
     def get_zp_self_energy_active(self):
@@ -735,9 +900,8 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=True,
+            shape='knl',
             )
-        # nkpt, nband, nomegase, nband
-        self.sigma = einsum('lkn->knl', self.sigma) # FIXME why??
         return self.sigma
 
     def get_zp_self_energy_sternheimer(self):
@@ -760,9 +924,8 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=True,
             only_active=False,
+            shape='knl',
             )
-        # nkpt, nband, nomegase, nband
-        self.sigma = einsum('lkn->knl', self.sigma) # FIXME why??
         return self.sigma
 
     def get_td_self_energy_active(self):
@@ -785,9 +948,8 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=True,
+            shape='knlt',
             )
-        # nkpt, nband, nomegase, nband
-        self.sigma = einsum('tlkn->knlt', self.sigma) # FIXME why??
         return self.sigma
 
     def get_td_self_energy_sternheimer(self):
@@ -810,9 +972,8 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=True,
             only_active=False,
+            shape='knlt',
             )
-        # nkpt, nband, nomegase, nband
-        self.sigma = einsum('tlkn->knlt', self.sigma) # FIXME why??
         return self.sigma
 
     def get_zpr_static_sternheimer(self):
@@ -825,6 +986,20 @@ class QptAnalyzer(object):
             dynamical=False,
             only_sternheimer=True,
             only_active=False,
+            real=True,
+            )
+        return self.zpr
+
+    def get_zpr_static_sternheimer_modes(self):
+        """Compute the q-point zpr contribution in a static scheme."""
+
+        self.zpr = self.get_self_energy(
+            mode=True,
+            temperature=False,
+            omega=False,
+            dynamical=False,
+            only_sternheimer=True,
+            only_active=False,
             ).real
         return self.zpr
 
@@ -840,7 +1015,8 @@ class QptAnalyzer(object):
             dynamical=False,
             only_sternheimer=False,
             only_active=False,
-            ).real
+            real=True,
+            )
         return self.zpr
 
     def get_zpr_dynamical(self):
@@ -855,7 +1031,8 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=False,
-            ).real
+            real=True,
+            )
         return self.zpr
 
     def get_tdr_static(self):
@@ -871,9 +1048,9 @@ class QptAnalyzer(object):
             dynamical=False,
             only_sternheimer=False,
             only_active=False,
-            ).real
-        # nkpt, nband, ntemp
-        self.tdr = einsum('tkn->knt', self.tdr) # FIXME why??
+            real=True,
+            shape='knt',
+            )
         return self.tdr
     
     def get_tdr_dynamical(self):
@@ -888,9 +1065,9 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=False,
-            ).real
-        # nkpt, nband, ntemp
-        self.tdr = einsum('tkn->knt', self.tdr) # FIXME why??
+            real=True,
+            shape='knt',
+            )
         return self.tdr
 
     def get_tdr_static_nosplit(self):
@@ -905,9 +1082,9 @@ class QptAnalyzer(object):
             dynamical=False,
             only_sternheimer=True,
             only_active=False,
-            ).real
-        # nkpt, nband, ntemp
-        self.tdr = einsum('tkn->knt', self.tdr) # FIXME why??
+            real=True,
+            shape='knt',
+            )
         return self.tdr
 
     def get_tdr_dynamical_active(self):
@@ -923,9 +1100,24 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=True,
-            ).real
-        # nkpt, nband, ntemp
-        self.tdr = einsum('tkn->knt', self.tdr) # FIXME why??
+            real=True,
+            shape='knt',
+            )
+        return self.tdr
+
+    def get_tdr_static_sternheimer(self):
+        """Compute the q-point zpr contribution in a static scheme."""
+
+        self.tdr = self.get_self_energy(
+            mode=False,
+            temperature=True,
+            omega=False,
+            dynamical=False,
+            only_sternheimer=True,
+            only_active=False,
+            real=True,
+            shape='knt',
+            )
         return self.tdr
 
     def get_zpr_dynamical_active(self):
@@ -941,6 +1133,24 @@ class QptAnalyzer(object):
             dynamical=True,
             only_sternheimer=False,
             only_active=True,
+            real=True,
+            )
+        # nkpt, nband, ntemp
+        return self.zpr
+
+    def get_zpr_dynamical_active_modes(self):
+        """
+        Compute the q-point contribution to the zero point
+        renormalization in a dynamical scheme,
+        taking only the active space contribution.
+        """
+        self.zpr = self.get_self_energy(
+            mode=True,
+            temperature=False,
+            omega=False,
+            dynamical=True,
+            only_sternheimer=False,
+            only_active=True,
             ).real
         # nkpt, nband, ntemp
         return self.zpr
@@ -958,9 +1168,28 @@ class QptAnalyzer(object):
             dynamical=False,
             only_sternheimer=False,
             only_active=False,
-            ).real
+            real=True,
+            )
         # nmode, nkpt, nband
-        return self.zpr  # FIXME use self.zpr_mode?
+        return self.zpr
+
+    def get_zpr_dynamical_modes(self):
+        """
+        Compute the q-point zpr contribution in a dynamical scheme,
+        with the transitions split between active and sternheimer.
+        Retain the mode decomposition of the zpr.
+        """
+        self.zpr = self.get_self_energy(
+            mode=True,
+            temperature=False,
+            omega=False,
+            dynamical=True,
+            only_sternheimer=False,
+            only_active=False,
+            real=True,
+            )
+        # nmode, nkpt, nband
+        return self.zpr
 
     def get_zpb_dynamical(self):
         """
@@ -978,9 +1207,13 @@ class QptAnalyzer(object):
         Only take the active space contribution.
         Returns: zpb[nkpt,nband,ntemp]
         """
-        self.tdb = self.get_broadening(mode=False, temperature=True,
-                                       omega=False, dynamical=True)
-        self.tdb = einsum('tkn->knt', self.tdb) # FIXME why??
+        self.tdb = self.get_broadening(
+            mode=False,
+            temperature=True,
+            omega=False,
+            dynamical=True,
+            shape='knt',
+            )
         return self.tdb
     
     def get_zpb_static(self):
@@ -999,9 +1232,13 @@ class QptAnalyzer(object):
         Only take the active space contribution.
         Returns: zpb[nkpt,nband,ntemp]
         """
-        self.tdb = self.get_broadening(mode=False, temperature=True,
-                                       omega=False, dynamical=False)
-        self.tdb = einsum('tkn->knt', self.tdb) # FIXME why??
+        self.tdb = self.get_broadening(
+            mode=False,
+            temperature=True,
+            omega=False,
+            dynamical=False,
+            shape='knt',
+            )
         return self.tdb
 
     def get_tdb_static_nosplit(self):
@@ -1078,5 +1315,43 @@ class QptAnalyzer(object):
             only_sternheimer=False,
             only_active=True,
             only_ddw=True,
-            ).real
+            real=True,
+            )
         return self.zpr
+
+    def get_tdr_ddw_active(self):
+        """
+        Compute the q-point zpr contribution in a static scheme
+        with the transitions split between active and sternheimer.
+        """
+        self.tdr = self.get_self_energy(
+            mode=False,
+            temperature=True,
+            omega=False,
+            dynamical=False,
+            only_sternheimer=False,
+            only_active=True,
+            only_ddw=True,
+            real=True,
+            shape='knt',
+            )
+        return self.tdr
+
+    def get_zp_fan_active(self):
+        """
+        Compute only the active part of fan term
+        """
+        self.zpaf = self.get_self_energy(
+            mode=False,
+            temperature=False,
+            omega=True,
+            dynamical=True,
+            only_sternheimer=False,
+            only_active=True,
+            only_fan=True,
+            )
+        # nkpt, nband, nomegase, nband
+        self.zpaf = einsum('lkn->knl', self.zpaf) # FIXME why??
+
+        return self.zpaf
+
