@@ -176,6 +176,20 @@ class PeriodicTableElement :
                         73 : 'Ta', 70 : 'Yb', 105 : 'Db', 66 : 'Dy', 110 : 'Ds', 53 : 'I', 49 : 'In', 92 : 'U', 39 : 'Y', 89 : 'Ac',\
                         47 : 'Ag', 77 : 'Ir', 95 : 'Am', 13 : 'Al', 33 : 'As', 18 : 'Ar', 79 : 'Au', 85 : 'At', 108 : 'Hs'}
 
+        self.table3 = {   1:    1.007940,  2:    4.002602,  3:    6.941000,  4:    9.012182,  5:   10.811000,  6:   12.011000,  7:   14.006740,\
+                          8:   15.999400,  9:   18.998404, 10:   20.179701, 11:   22.989767, 12:   24.305000, 13:   26.981539, 14:   28.085501,\
+                          15:   30.973763, 16:   32.066002, 17:   35.452702, 18:   39.948002, 19:   39.098301, 20:   40.077999, 21:   44.955910,\
+                          22:   47.880001, 23:   50.941502, 24:   51.996101, 25:   54.938049, 26:   55.847000, 27:   58.933201, 28:   58.689999, 29:   63.546001, 30:   65.389999,\
+                          31:   69.723000, 32:   72.610001, 33:   74.921593, 34:   78.959999, 35:   79.903999, 36:   83.800003, 37:   85.467796, 38:   87.620003, 39:   88.905853,\
+                          40:   91.223999, 41:   92.906380, 42:   95.940002, 43:   98.906197, 44:  101.070000, 45:  102.905502, 46:  106.419998, 47:  107.868202, 48:  112.411003,\
+                          49:  114.820000, 50:  118.709999, 51:  121.752998, 52:  127.599998, 53:  126.904472, 54:  131.289993, 55:  132.905426, 56:  137.326996, 57:  138.905502,\
+                          58:  140.115005, 59:  140.907654, 60:  144.240005, 61:  147.910004, 62:  150.360001, 63:  151.964996, 64:  157.250000, 65:  158.925339, 66:  162.500000, \
+                          67:  164.930313, 68:  167.259995, 69:  168.934204, 70:  173.039993, 71:  174.966995, 72:  178.490005, 73:  180.947906, 74:  183.850006, 75:  186.207001, \
+                          76:  190.199997, 77:  192.220001, 78:  195.080002, 79:  196.966537, 80:  200.589996, 81:  204.383301, 82:  207.199997, 83:  208.980377, 84:  209.000000, \
+                          85:  210.000000, 86:  222.000000, 87:  223.000000, 88:  226.025406, 89:  230.000000, 90:  232.038101, 91:  231.035904, 92:  238.028900, 93:  237.048203, \
+                          94:  242.000000, 95:  243.000000, 96:  247.000000, 97:  247.000000, 98:  249.000000, 99:  254.000000,100:  253.000000,101:  256.000000,102:  254.000000,\
+                          103:  257.000000}
+
     def getZnucl(self,name):
         try :
             return self.table1[name]
@@ -188,8 +202,11 @@ class PeriodicTableElement :
         except:
             return 'Unknown Element'
 
-
-
+    def getMass(self,znucl):
+        try :
+            return self.table3[znucl]
+        except:
+            return 'Unknown Element'
 
 
 #----------------------------------------------------------------#
