@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # Author: Samuel Ponc\'e + Yannick Gillet
-# Date: 30/04/2013 -- 11/09/2014 -- 07/08/2015
-# Version: 1.4
+# Date: 30/04/2013 -- 11/09/2014 -- 07/08/2015 -- 21/12/2020
+# Version: 1.5
 # This is the executable script 
 
-from __future__ import division, print_function
+#from __future__ import division, print_function
 import sys
 import os
 import copy
@@ -53,7 +53,7 @@ def main():
    | |_) | |_) |____| __/ _ \ '_ ` _ \| '_ \ / _ \ '__/ _` | __| | | | '__/ _ \ 
    |  __/|  __/_____| ||  __/ | | | | | |_) |  __/ | | (_| | |_| |_| | | |  __/ 
    |_|   |_|         \__\___|_| |_| |_| .__/ \___|_|  \__,_|\__|\__,_|_|  \___| 
-                                      |_|                              Version 1.3         
+                                      |_|                              Version 1.5         
   """
 
   header +=  '\nThis script compute the static/dynamic zero-point motion \n\
@@ -64,7 +64,7 @@ def main():
   print(header)
 
   # Enter the number of cpu on which you want to multi-thread
-  user_input = raw_input('Enter the number of cpu on which you want to multi-thread\n')
+  user_input = input('Enter the number of cpu on which you want to multi-thread\n')
   nb_cpus = user_input
   try:
     nb_cpus = int(user_input)
@@ -72,7 +72,7 @@ def main():
     raise Exception('The value you enter is not an integer!')
   
   # Type of calculation the user want to perform
-  user_input = raw_input('Define the type of calculation you want to perform. Type:\n\
+  user_input = input('Define the type of calculation you want to perform. Type:\n\
                          1 if you want to run a non-adiabatic AHC calculation\n \
                         2 if you want to run a static AHC calculation\n \
                         3 if you want to run a static AHC calculation without control on active space (not recommended !)\n \
@@ -80,7 +80,7 @@ def main():
   type = N.int(user_input)
   
   # Define the output file name
-  user_input = raw_input('Enter name of the output file\n')
+  user_input = input('Enter name of the output file\n')
   output = user_input.strip()
   
   if type <= 0 or type > 3:
@@ -89,7 +89,7 @@ def main():
   
   # Enter the value of the smearing parameter for dynamic AHC
   if type == 1 or type == 2:
-    user_input = raw_input('Enter value of the smearing parameter for AHC (in eV)\n')
+    user_input = input('Enter value of the smearing parameter for AHC (in eV)\n')
     smearing = N.float(user_input)
     smearing = smearing/Ha2eV
   elif type == 3:
@@ -100,11 +100,11 @@ def main():
   
   # Enter the value of the smearing parameter for Gaussian broadening
   if type == 1 or type == 2:
-    user_input = raw_input('Enter value of the Gaussian broadening for the Eliashberg function and PDOS (in eV)\n')
+    user_input = input('Enter value of the Gaussian broadening for the Eliashberg function and PDOS (in eV)\n')
     gaussian_smearing = N.float(user_input)
     gaussian_smearing = gaussian_smearing/Ha2eV
   elif type == 3:
-    user_input = raw_input('Enter value of the Gaussian broadening for the PDOS (in eV)\n')
+    user_input = input('Enter value of the Gaussian broadening for the PDOS (in eV)\n')
     gaussian_smearing = N.float(user_input)
     gaussian_smearing = gaussian_smearing/Ha2eV
   else:
@@ -112,18 +112,18 @@ def main():
   
   # Enter the value of the emergy range for the PDOS and Eliashberg calculations
   if type == 1 or type == 2:
-    user_input = raw_input('Enter the energy range for the PDOS and Eliashberg calculations (in eV): [e.g. 0 0.5] \n')
+    user_input = input('Enter the energy range for the PDOS and Eliashberg calculations (in eV): [e.g. 0 0.5] \n')
     energy_range = user_input.split()
     energy = N.linspace(N.float(energy_range[0])/Ha2eV,N.float(energy_range[1])/Ha2eV,500)  
   elif type == 3:
-    user_input = raw_input('Enter the energy range for the PDOS (in eV): [e.g. 0 0.5] \n')
+    user_input = input('Enter the energy range for the PDOS (in eV): [e.g. 0 0.5] \n')
     energy_range = user_input.split()
     energy = N.linspace(N.float(energy_range[0])/Ha2eV,N.float(energy_range[1])/Ha2eV,500)  
   else:
     energy = None
   
   # Temperature dependence analysis
-  user_input = raw_input('Introduce the min temperature, the max temperature and the temperature steps. e.g. 0 200 50 for (0,50,100,150)\n')
+  user_input = input('Introduce the min temperature, the max temperature and the temperature steps. e.g. 0 200 50 for (0,50,100,150)\n')
   temp_info = user_input.split()
   if(len(temp_info) == 1):
     # If the user specifies only one value, it is the temperature !
@@ -134,7 +134,7 @@ def main():
   # Lifetime is always activated now !
   lifetime = True
   # Broadening lifetime of the electron
-  #user_input = raw_input('Do you want to compute the lifetime of the electrons? [y/n]\n')
+  #user_input = input('Do you want to compute the lifetime of the electrons? [y/n]\n')
   #tmp =user_input.split()[0]
   #if tmp == 'y':
   #  lifetime = True
@@ -142,7 +142,7 @@ def main():
   #  lifetime = False
   
   # Get the nb of Q-points from user 
-  user_input = raw_input('Enter the number of Q-points you have\n')
+  user_input = input('Enter the number of Q-points you have\n')
   try:
     nbQ = int(user_input)
   except ValueError:
@@ -151,7 +151,7 @@ def main():
   # Get the path of the DDB files from user
   DDB_files = []
   for ii in N.arange(nbQ):
-    user_input = raw_input('Enter the name of the %s DDB file\n' %ii)
+    user_input = input('Enter the name of the %s DDB file\n' %ii)
     if len(user_input.split()) != 1:
       raise Exception("You should provide only 1 file")
     else: # Append and TRIM the input string with STRIP
@@ -165,7 +165,7 @@ def main():
   # Get the path of the eigq files from user
   eigq_files = []
   for ii in N.arange(nbQ):
-    user_input = raw_input('Enter the name of the %s eigq file\n' %ii)
+    user_input = input('Enter the name of the %s eigq file\n' %ii)
     if len(user_input.split()) != 1:
       raise Exception("You should provide only 1 file")
     else:
@@ -174,7 +174,7 @@ def main():
   # Get the path of the EIGR2D files from user
   EIGR2D_files = []
   for ii in N.arange(nbQ):
-    user_input = raw_input('Enter the name of the %s EIGR2D file\n' %ii)
+    user_input = input('Enter the name of the %s EIGR2D file\n' %ii)
     if len(user_input.split()) != 1:
       raise Exception("You should provide only 1 file")
     else:
@@ -184,7 +184,7 @@ def main():
   if type == 1 or type == 2:
     GKK_files = []
     for ii in N.arange(nbQ):
-      user_input = raw_input('Enter the name of the %s GKK file\n' %ii)
+      user_input = input('Enter the name of the %s GKK file\n' %ii)
       if len(user_input.split()) != 1:
         raise Exception("You should provide only 1 file")
       else:
@@ -193,7 +193,7 @@ def main():
     GKK_files = []
   
   # Take the EIG at Gamma
-  user_input = raw_input('Enter the name of the unperturbed EIG.nc file at Gamma\n')
+  user_input = input('Enter the name of the unperturbed EIG.nc file at Gamma\n')
   if len(user_input.split()) != 1:
     raise Exception("You sould only provide 1 file")
   else:
@@ -257,13 +257,15 @@ def main():
   eig0_pass = copy.deepcopy(eig0.EIG)
   
   if type == 1 or type == 2:
-    total = zpm(zip(nbqpt,wtq,eigq_files,DDB_files,EIGR2D_files,GKK_files),ddw_save,ddw_save2,nb_cpus,type,\
+    arguments = list(zip(nbqpt,wtq,eigq_files,DDB_files,EIGR2D_files,GKK_files))   
+    total = zpm(arguments,ddw_save,ddw_save2,nb_cpus,type,\
                all_temp,smearing,eig0_pass,degen,energy,gaussian_smearing)
   elif type == 3:
-    total = zpm(zip(nbqpt,wtq,eigq_files,DDB_files,EIGR2D_files),ddw_save,ddw_save2,nb_cpus,type,\
+    arguments = list(zip(nbqpt,wtq,eigq_files,DDB_files,EIGR2D_files))  
+    total = zpm(arguments,ddw_save,ddw_save2,nb_cpus,type,\
                all_temp,smearing,eig0_pass,degen,energy,gaussian_smearing)
   total_corr = total.total_corr
-  
+
   if (abs(EIGR2D.wtq) > tol6):
     total_wtq = total.total_wtq
     print("Total weigth is ",total_wtq)
