@@ -5,9 +5,9 @@
 
 #ifdef HAVE_LIBTETRA_ABINIT
 #include "abi_common.h"
-#  define TETRA_ALLOCATE(ARR,SIZE) ABI_ALLOCATE(ARR,SIZE)
-#  define TETRA_DEALLOCATE(ARR)  ABI_DEALLOCATE(ARR)
-#  define TETRA_ERROR(MSG) MSG_ERROR(MSG)
+#  define TETRA_ALLOCATE(ARR,SIZE) ABI_MALLOC(ARR,SIZE)
+#  define TETRA_DEALLOCATE(ARR)  ABI_FREE(ARR)
+#  define TETRA_ERROR(MSG) ABI_ERROR(MSG)
 #  define USE_MEMORY_PROFILING use m_profiling_abi
 #  define USE_MSG_HANDLING use m_errors, only : msg_hndl
 
