@@ -53,7 +53,7 @@ ALL_BINARIES = [
     "optic",
     "tdep",
     "testtransposer",
-    "ujdet",
+    "lruj",
 ]
 
 
@@ -234,7 +234,7 @@ def ctags(ctx):
     Update ctags file.
     """
     with cd(ABINIT_ROOTDIR):
-        cmd = "ctags -R --langmap=fortran:+.finc.f90 shared/ src/"
+        cmd = "ctags -R --langmap=fortran:+.finc.f90,c:.c.cu shared/ src/"
         print("Executing:", cmd)
         ctx.run(cmd, pty=True)
         #ctx.run('ctags -R --exclude="_*"', pty=True)
@@ -250,7 +250,7 @@ def fgrep(ctx, pattern):
     #    -i - case-insensitive search
     #    --include=\*.${file_extension} - search files that match the extension(s) or file pattern only
     with cd(ABINIT_ROOTDIR):
-        cmd  = 'grep -r -i --color --include "*[.F90,.f90,.finc]" "%s" src shared' % pattern
+        cmd  = 'grep -r -i --color --include "*[.F90,.f90,.finc,.c,.cu,.cpp]" "%s" src shared' % pattern
         #cmd  = 'grep -r -i --color --include "*.F90" "%s" src shared' % pattern
         print("Executing:", cmd)
         ctx.run(cmd, pty=True)
@@ -432,9 +432,8 @@ def submodules(ctx):
     """Update submodules."""
     with cd(ABINIT_ROOTDIR):
         # https://stackoverflow.com/questions/1030169/easy-way-to-pull-latest-of-all-git-submodules
-        ctx.run("git submodule update --remote --init")
-        #ctx.run("git submodule update --remote")
-        ctx.run("git submodule update --recursive --remote")
+        ctx.run("git submodule update --remote --init", pty=True)
+        ctx.run("git submodule update --recursive --remote", pty=True)
 
 @task
 def branchoff(ctx, start_point):
@@ -458,6 +457,27 @@ def branchoff(ctx, start_point):
     run("git push origin HEAD")
 
 
+@task
+def dryrun_merge(ctx, start_point):
+    """"Merge `remote/branch` in dry-run mode."""
+
+    def run(cmd):
+        cprint(f"Executing: `{cmd}`", color="green")
+        ctx.run(cmd)
+
+    run(f"git merge --no-commit --no-ff {start_point}")
+
+    print("""
+To examine the staged changes:
+
+    $ git diff --cached
+
+And you can undo the merge, even if it is a fast-forward merge:
+
+$ git merge --abort
+""")
+
+
 @task
 def watchdog(ctx, jobs="auto", sleep_time = 5):
     """
