@@ -11,8 +11,8 @@ keywords = [
 
 #: List of input files
 inp_files = [
-"t01.in",
-"t02.in",
-"t03.in",
-"t04.in",
+"t01.abi",
+"t02.abi",
+"t03.abi",
+"t04.abi",
 ]
