@@ -12,30 +12,30 @@ keywords = [
 
 #: List of input files
 inp_files = [
-"t00.in",
-"t01.in",
-"t02.in",
-"t03.in",
-"t04.in",
-"t05.in",
-"t06.in",
-"t07.in",
-"t09.in",
-"t10.in",
-"t11.in",
-"t12.in",
-"t14.in",
-"t16.in",
-"t17.in",
-"t18.in",
-"t20.in",
-"t21.in",
-"t22.in",
-"t23.in",
-"t31.in",
-"t32.in",
-"-t33.in",
-"-t34.in",
-"-t35.in",
-"-t36.in",
+"t00.abi",
+"t01.abi",
+"t02.abi",
+"t03.abi",
+"t04.abi",
+"t05.abi",
+"t06.abi",
+"t07.abi",
+"t09.abi",
+"t10.abi",
+"t11.abi",
+"t12.abi",
+"t14.abi",
+#"t16.abi",
+#"t17.abi",
+#"t18.abi",
+"t20.abi",
+"t21.abi",
+"t22.abi",
+"t23.abi",
+"t31.abi",
+"t32.abi",
+"-t33.abi",
+"-t34.abi",
+"-t35.abi",
+"-t36.abi",
 ]
