@@ -21,22 +21,22 @@ subsuites = [
 
 #: List of input files
 inp_files = [
-"tsv2_81.in",
-"tsv2_82.in",
-"tsv3_03.in",
-"tsv3_04.in",
-"tsv3_05.in",
-"tsv4_55.in",
-"tsv4_78.in",
-"tsv4_80.in",
-"tsv4_90.in",
-"tsv5_112.in",
-"tsv5_113.in",
-"tsv6_121.in",
-"tsv6_122.in",
-"tsv6_123.in",
-"tsv6_124.in",
-"tsv6_125.in",
-"tsv6_126.in",
-"tsv7_70.in",
+"tsv2_81.abi",
+"tsv2_82.abi",
+"tsv3_03.abi",
+"tsv3_04.abi",
+"tsv3_05.abi",
+"tsv4_55.abi",
+"tsv4_78.abi",
+"tsv4_80.abi",
+"tsv4_90.abi",
+"tsv5_112.abi",
+"tsv5_113.abi",
+"tsv6_121.abi",
+"tsv6_122.abi",
+"tsv6_123.abi",
+"tsv6_124.abi",
+"tsv6_125.abi",
+"tsv6_126.abi",
+"tsv7_70.abi",  # Note that the test v7#70 has been replaced by another test
 ]
